@@ -1,11 +1,11 @@
 from pathlib import Path
 
-__version__ = "1.1.7"
+__version__ = "1.1.11"
 
 DATAFILE = Path(__file__).parent.absolute()/"data/untouchable.dat"
 USERFILE = Path.home()/".python-negar"
 
-INFO="""قابلیت های ویراستار ' نگار  ':
+INFO=f"""قابلیت های ویراستار ' نگار  ' -- نسخه {__version__} :
 * جایگزینی
 	╛═ خط تیره های پیاپی نظیر (--) و (---) با معادل های استاندارد شان
 	╛═ سه نقطه ی پیاپی (...) با کاراکتر استانداردش در زبان فارسی
@@ -16,7 +16,7 @@ INFO="""قابلیت های ویراستار ' نگار  ':
 * تنظیم فاصله
 	╛═ کلماتی که با 'ی' پسوند همراه هستند مانند 'همه ی ' -- و البته امکان جایگزینی آن با حمزه 'ء' ( در صورت انتخاب کاربر )
 	╛═ پرانتز ها  یا دیگر علایم ؛ ( نگار )
-	╛═ علائم نقطه‌گذاری ؛ بدون فاصله از قبل و با یک فاصله از بعد به استثنای اعداد اعشاری مانند 12.4
+  ╛═ علائم نقطه‌گذاری ؛ بدون فاصله از قبل و با یک فاصله از بعد به استثنای اعداد اعشاری/نسخه نرم‌افزاری مانند	12.4/1.2.4
 	╛═ در پیشوند کلمات با نیم‌فاصله نظیر ' می شود '، ' میشود '، ' بی شک '، ' بیشک ' , ' خانه اش '، ' وظیفه شناس ' ، ' کمک تان '  و یا ' نمیرود '
 	╛═ در پسوند کلمات با نیم‌فاصله نظیر کتابها، خوشترین -- و البته امکان عدم تنظیم (در صورت انتخاب کاربر)
 
