@@ -1,7 +1,7 @@
 def main():
     try:
-        from negar_gui import gui
-        gui.main()
+        from negar_gui import main
+        main.main()
     except ModuleNotFoundError:
         print("Install `negar-gui` to have a GUI! :D")
         print("==>> pip install negar-gui")
